From b72ce987283d3f8afb55a66c53118a1c160f1fe0 Mon Sep 17 00:00:00 2001
From: Raghav Gururajan <raghavgururajan@disroot.org>
Date: Sat, 28 Mar 2020 18:10:01 -0400
Subject: [PATCH 11/11] gnu: packages: linphone: Add ortp

* gnu/packages/linphone.scm (ortp): New variable.
---
 gnu/packages/linphone.scm | 39 +++++++++++++++++++++++++++++++++++++++
 1 file changed, 39 insertions(+)

diff --git a/gnu/packages/linphone.scm b/gnu/packages/linphone.scm
index fb4ec5f803..c8735bfa87 100644
--- a/gnu/packages/linphone.scm
+++ b/gnu/packages/linphone.scm
@@ -21,6 +21,8 @@
   #:use-module (gnu packages)
   #:use-module (gnu packages base)
   #:use-module (gnu packages compression)
+  #:use-module (gnu packages documentation)
+  #:use-module (gnu packages graphviz)
   #:use-module (gnu packages java)
   #:use-module (gnu packages ncurses)
   #:use-module (gnu packages pth)
@@ -232,3 +234,40 @@ supports concurrent channels encoding and decoding for multi call application
 such as conferencing.")
  (home-page "https://gitlab.linphone.org/BC/public/belcard")
  (license license:gpl3+)))
+
+(define-public ortp
+ (package
+  (name "ortp")
+   (version "1.0.2")
+   (source
+    (origin
+     (method url-fetch)
+     (uri
+      (string-append "https://www.linphone.org/releases/sources/" name
+                     "/" name "-" version ".tar.gz"))
+     (sha256
+      (base32 "016qg0lmdgmqh2kv19w9qhi4kkiyi5h1xp35g2s65b1j8ccm25d5"))))
+ (build-system cmake-build-system)
+ (arguments
+  `(#:tests? #f ; No test target
+    #:configure-flags
+     (list
+      "-DENABLE_SHARED=YES"
+      "-DENABLE_STATIC=YES"
+      "-DENABLE_DOC=YES"
+      "-DENABLE_NTP_TIMESTAMP=NO" ; "ORTP_TIMESTAMP" redefined [-Werror]
+      "-DENABLE_PERF=YES"
+      "-DENABLE_STRICT=YES"
+      "-DENABLE_TESTS=YES"
+      "-DENABLE_DEBUG_LOGS=YES")))
+ (native-inputs
+  `(("dot" ,graphviz)
+    ("doxygen" ,doxygen)
+    ("threads" ,pth)))
+ (propagated-inputs
+  `(("bctoolbox" ,bctoolbox)))
+ (synopsis "Belledonne Communications RTP Library")
+ (description "oRTP is a C library implementing the RTP protocol.  It uses
+RFC 3550 standard.")
+ (home-page "https://gitlab.linphone.org/BC/public/ortp")
+ (license license:gpl2+)))
-- 
2.26.0

